from behave import when

from servicecatalog_puppet import config, sdk

from . import constants

roles = {
    "PuppetCodePipelineRole": 'puppet_code_pipeline_role_permission_boundary',
    "SourceRolePermissionsBoundary": "source_role_permissions_boundary",
    "PuppetGenerateRolePermissionBoundary": "puppet_generate_role_permission_boundary",
    "PuppetDeployRolePermissionBoundary": "puppet_deploy_role_permission_boundary",
    "PuppetProvisioningRolePermissionsBoundary": "puppet_provisioning_role_permissions_boundary",
    "CloudFormationDeployRolePermissionsBoundary": "cloud_formation_deploy_role_permissions_boundary",

}


@when(u'I bootstrap a "{account_type}" account with version "{version}" and set an IAM Boundary for "{role}"')
def step_impl(context, account_type, version, role):
    if account_type == "puppet":
        args = {
            "with_manual_approvals": False
        }
        args[roles.get(role)] = constants.BOUNDARY_ARN_TO_USE
        sdk.bootstrap(**args)

    elif account_type == "spoke":
        sdk.bootstrap_spoke(
            config.get_puppet_account_id(),
            "arn:aws:iam::aws:policy/AdministratorAccess"
        )


@when(u'I bootstrap a "{account_type}" account with version "{version}"')
def step_impl(context, account_type, version):
    if account_type == "puppet":
        sdk.bootstrap(False)
    elif account_type == "spoke":
        sdk.bootstrap_spoke(
            config.get_puppet_account_id(),
            "arn:aws:iam::aws:policy/AdministratorAccess"
        )



from behave import given, when, then, step

from servicecatalog_puppet import config, constants, sdk
from betterboto import client as betterboto_client


@given(u'a "{account_type}" account has not been bootstrapped')
def step_impl(context, account_type):
    if account_type == "puppet":
        sdk.uninstall()
    elif account_type == "spoke":
        sdk.release_spoke()


@given(u'a "{account_type}" account has been bootstrapped with version "{version}"')
def step_impl(context, account_type, version):
    with betterboto_client.ClientContextManager('cloudformation') as cloudformation:
        if account_type == "puppet":
            stacks = cloudformation.describe_stacks_single_page(
                StackName=constants.BOOTSTRAP_STACK_NAME
            ).get('Stacks', [])
        elif account_type == "spoke":
            stacks = cloudformation.describe_stacks_single_page(
                StackName=f"{constants.BOOTSTRAP_STACK_NAME}-spoke"
            ).get('Stacks', [])

        completed = False
        for stack in stacks:
            if stack.get('StackStatus') == 'CREATE_COMPLETE':
                completed = True
                break

        if not completed:
            raise Exception("not bootstrapped correctly or at all")


@given(u'the config has been set')
def step_impl(context):
    sdk.upload_config({
        "regions": [
            'eu-west-1',
            'eu-west-2',
        ],
        "should_collect_cloudformation_events": False,
        "should_forward_events_to_eventbridge": False,
        "should_forward_failures_to_opscenter": False,
    })



from behave import given, when, then, step

from servicecatalog_puppet import config, constants, sdk
from betterboto import client as betterboto_client


@then(u'the "{account_type}" account is bootstrapped with version "{version}" and "{role}" has an IAM Boundary')
def step_impl(context, account_type, version, role):
    param_name = ""

    if account_type == "spoke":
        param_name = constants.SPOKE_VERSION_SSM_PARAM_NAME
    elif account_type == "puppet":
        param_name = constants.PUPPET_VERSION_SSM_PARAM_NAME

    with betterboto_client.ClientContextManager('ssm') as ssm:
        ssm.get_parameter(Name=param_name)


@then(u'the "{account_type}" account is bootstrapped with version "{version}"')
def step_impl(context, account_type, version):
    param_name = ""

    if account_type == "spoke":
        param_name = constants.SPOKE_VERSION_SSM_PARAM_NAME
    elif account_type == "puppet":
        param_name = constants.PUPPET_VERSION_SSM_PARAM_NAME

    with betterboto_client.ClientContextManager('ssm') as ssm:
        ssm.get_parameter(Name=param_name)




# -*- coding: utf-8 -*-

# DO NOT EDIT THIS FILE!
# This file has been autogenerated by dephell <3
# https://github.com/dephell/dephell

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


import os.path

readme = ''
here = os.path.abspath(os.path.dirname(__file__))
readme_path = os.path.join(here, 'README.rst')
if os.path.exists(readme_path):
    with open(readme_path, 'rb') as stream:
        readme = stream.read().decode('utf8')


setup(
    long_description=readme,
    name='aws-service-catalog-puppet',
    version='0.76.3',
    description='Making it easier to deploy ServiceCatalog products',
    python_requires='>=3.7',
    project_urls={"homepage": "https://github.com/awslabs/aws-service-catalog-puppet-framework", "repository": "https://github.com/awslabs/aws-service-catalog-puppet-framework"},
    author='Eamonn Faherty',
    author_email='aws-service-catalog-tools@amazon.com',
    classifiers=['Development Status :: 5 - Production/Stable', 'Intended Audience :: Developers', 'Programming Language :: Python :: 3', 'License :: OSI Approved :: Apache Software License', 'Operating System :: OS Independent', 'Natural Language :: English'],
    entry_points={"console_scripts": ["servicecatalog-puppet = servicecatalog_puppet.cli:cli"]},
    packages=['servicecatalog_puppet', 'servicecatalog_puppet.workflow'],
    package_dir={"": "."},
    package_data={"servicecatalog_puppet": ["*.yaml", "data/account-vending/*.json", "data/manifest_utils/*.yaml", "data/manifest_utils/accounts/*.yaml", "data/manifest_utils/tags/*.yaml", "data/manifest_utils_for_spoke_local_portfolios/*.yaml", "manifests/*.yaml", "templates/*.j2"]},
    install_requires=['better-boto==0.28.0', 'boto3', 'cfn-flip==1.2.3', 'click==7.0', 'colorclass==2.2.0', 'jinja2==2.10.1', 'luigi==2.8.9', 'progressbar==2.5', 'psutil==5.7.0', 'pykwalify==1.7.0', 'pyyaml==5.1', 'requests==2.22.0', 'terminaltables==3.1.0'],
    extras_require={"dev": ["behave==1.*,>=1.2.6", "codecov==2.*,>=2.1.7", "pylint==2.*,>=2.5.3", "pytest>=5.3.2", "pytest-cov==2.*,>=2.10.0", "pytest-datadir==1.*,>=1.3.1", "pytest-mock==3.*,>=3.1.1"]},
)
